==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/architecture/statemachine/State.java <==
package io.ciera.tool.sql.architecture.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.invocable.InvocableObject;
import io.ciera.tool.sql.architecture.statemachine.StateMachine;
import io.ciera.tool.sql.architecture.statemachine.StateTransition;
import io.ciera.tool.sql.architecture.statemachine.StateTransitionSet;
import io.ciera.tool.sql.architecture.statemachine.TransitionTableRow;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineState;


public interface State extends IModelInstance<State,Sql> {

    // attributes
    public String getSm_name() throws XtumlException;
    public void setSm_name( String ref_sm_name ) throws XtumlException;
    public void setSm_package( String ref_sm_package ) throws XtumlException;
    public String getSm_package() throws XtumlException;
    public String getName() throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public void setFinal( boolean m_final ) throws XtumlException;
    public boolean getFinal() throws XtumlException;
    public void setNumber( int m_number ) throws XtumlException;
    public int getNumber() throws XtumlException;
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException;
    public UniqueId getSM_ID() throws XtumlException;
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException;
    public UniqueId getSMstt_ID() throws XtumlException;


    // operations
    public void render() throws XtumlException;
    public void render_decl() throws XtumlException;


    // selections
    default public void setR427_is_a_InvocableObject( InvocableObject inst ) {}
    public InvocableObject R427_is_a_InvocableObject() throws XtumlException;
    default public void setR4751_StateMachine( StateMachine inst ) {}
    public StateMachine R4751_StateMachine() throws XtumlException;
    default public void setR4754_is_start_state_for_TransitionTableRow( TransitionTableRow inst ) {}
    public TransitionTableRow R4754_is_start_state_for_TransitionTableRow() throws XtumlException;
    default public void addR4757_StateTransition( StateTransition inst ) {}
    default public void removeR4757_StateTransition( StateTransition inst ) {}
    public StateTransitionSet R4757_StateTransition() throws XtumlException;
    default public void setR4758_is_basis_for_StateMachineState( StateMachineState inst ) {}
    public StateMachineState R4758_is_basis_for_StateMachineState() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/statemachine/State.java <==
package io.ciera.tool.sql.architecture.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.invocable.InvocableObject;
import io.ciera.tool.sql.architecture.statemachine.StateMachine;
import io.ciera.tool.sql.architecture.statemachine.StateTransition;
import io.ciera.tool.sql.architecture.statemachine.StateTransitionSet;
import io.ciera.tool.sql.architecture.statemachine.TransitionTableRow;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineState;


public interface State extends IModelInstance<State,Sql> {

    // attributes
    public String getSm_name() throws XtumlException;
    public void setSm_name( String ref_sm_name ) throws XtumlException;
    public void setSm_package( String ref_sm_package ) throws XtumlException;
    public String getSm_package() throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public boolean getFinal() throws XtumlException;
    public void setFinal( boolean m_final ) throws XtumlException;
    public void setNumber( int m_number ) throws XtumlException;
    public int getNumber() throws XtumlException;


    // operations
    public void render() throws XtumlException;
    public void render_decl() throws XtumlException;


    // selections
    default public void setR427_is_a_InvocableObject( InvocableObject inst ) {}
    public InvocableObject R427_is_a_InvocableObject() throws XtumlException;
    default public void setR4751_StateMachine( StateMachine inst ) {}
    public StateMachine R4751_StateMachine() throws XtumlException;
    default public void setR4754_is_start_state_for_TransitionTableRow( TransitionTableRow inst ) {}
    public TransitionTableRow R4754_is_start_state_for_TransitionTableRow() throws XtumlException;
    default public void addR4757_StateTransition( StateTransition inst ) {}
    default public void removeR4757_StateTransition( StateTransition inst ) {}
    public StateTransitionSet R4757_StateTransition() throws XtumlException;
    default public void setR4758_StateMachineState( StateMachineState inst ) {}
    public StateMachineState R4758_StateMachineState() throws XtumlException;


}
